from unittest.mock import patch

from django.test import SimpleTestCase

from django_aws_api_gateway_websockets.management.commands.clearWebSocketSessions import (
    Command,
)


class ClearWebSocketSessionTestCase(SimpleTestCase):
    """Test the management command takes the expected action(s)"""

    @patch(
        "django_aws_api_gateway_websockets.management.commands.clearWebSocketSessions.WebSocketSession"
    )
    def test_handle(self, MockWebSocketSession):
        cmd = Command()
        cmd.handle()
        MockWebSocketSession.objects.filter.assert_called_with(connected=False)
        MockWebSocketSession.objects.filter.return_value.delete.assert_called_with()



# test_settings.py

DEBUG = True

SECRET_KEY = "fake-key"

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django_aws_api_gateway_websockets",
]

MIDDLEWARE = [
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "django.middleware.security.SecurityMiddleware",
]

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

AUTH_USER_MODEL = "auth.User"



# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html
from __future__ import annotations

import os
import sys
import tomllib
from pathlib import Path

import django

sys.path.insert(0, os.path.abspath(".."))
os.environ["DJANGO_SETTINGS_MODULE"] = "tests.settings"
django.setup()

from django.conf import settings  # noqa

import django_aws_api_gateway_websockets  # noqa

# -- Path setup --------------------------------------------------------------

here = Path(__file__).parent.resolve()
sys.path.insert(0, str(here / ".."))

# -- Project information -----------------------------------------------------

project = "Django-AWS-Api-Gateway-WebSockets"
copyright = "2021 Steven Mapes"
author = "Steven Mapes"

# The version info for the project you're documenting, acts as replacement
# for |version| and |release|, also used in various other places throughout
# the built documents.


def _get_version() -> str:
    with (here / ".." / "pyproject.toml").open("rb") as fp:
        data = tomllib.load(fp)
    version: str = data["project"]["version"]
    return version


version = _get_version()
release = version

# -- General configuration ---------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.viewcode",
    "sphinx.ext.intersphinx",
]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = [
    ".venv",
    "_build",
]

# -- Options for HTML output -------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
html_theme = "furo"
html_theme_options = {
    "dark_css_variables": {
        "admonition-font-size": "100%",
        "admonition-title-font-size": "100%",
    },
    "light_css_variables": {
        "admonition-font-size": "100%",
        "admonition-title-font-size": "100%",
    },
}

# The name of an image file (within the static path) to use as favicon
# of the docs.  This file should be a Windows icon file (.ico) being
# 16x16 or 32x32 pixels large.
html_favicon = "_static/favicon.ico"

# Add any paths that contain custom static files (such as style sheets)
# here, relative to this directory. They are copied after the builtin
# static files, so a file named "default.css" will overwrite the builtin
# "default.css".
html_static_path = ["_static"]

epub_exclude_files = [
    "_static/favicon.ico",
]

# -- Options for LaTeX output ------------------------------------------

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass
# [howto/manual]).
latex_documents = [
    (
        "index",
        "django-aws-api-gateway-webSockets.tex",
        "Django-AWS-Api-Gateway-WebSockets Documentation",
        "Steven Mapes",
        "manual",
    ),
]

# -- Options for Intersphinx -------------------------------------------

intersphinx_mapping = {
    "django": (
        "https://docs.djangoproject.com/en/stable/",
        "https://docs.djangoproject.com/en/stable/_objects/",
    ),
}



from io import StringIO
from unittest.mock import patch

from django.core.management import call_command
from django.test import SimpleTestCase


class CreateCustomDomainTestCase(SimpleTestCase):
    """Test the management command used to invoke the create_gateway method"""

    def call_command(self, *args, **kwargs):
        """Wrapper to allow the management command to be run"""
        call_command(
            "createCustomDomain",
            *args,
            stdout=StringIO(),
            stderr=StringIO(),
            **kwargs,
        )

    @patch(
        "django_aws_api_gateway_websockets.management.commands.createCustomDomain.ApiGateway"
    )
    def test_add_argument(self, MockApiGateway):
        self.call_command("--pk=123")
        MockApiGateway.objects.get.assert_called_with(
            pk=123, api_created=True, custom_domain_created=False
        )
        MockApiGateway.objects.get.return_value.create_custom_domain.assert_called_with()



import sys

from django.urls import resolve

from django_aws_api_gateway_websockets.models import ApiGatewayAdditionalRoute


class AddWebSocketRouteToContextMixin:
    """Adds the APIGateway Route to the Content"""

    websocket_route_key = (
        "default"  # Ensure you override this if you are not using the default route
    )
    channel_name = ""

    def get_context_data(self, **kwargs) -> dict:
        """Adds the Websocket route connection to the context"""

        context = super().get_context_data(**kwargs)
        context["api_gateway_route"] = (
            ApiGatewayAdditionalRoute.objects.filter(route_key=self.websocket_route_key)
            .select_related("api_gateway")
            .first()
        )
        context["channel_name"] = self.channel_name
        return context


class AppChannelWebSocketMixin(AddWebSocketRouteToContextMixin):
    """Adds the websocket setup where the route key and channel name are the name of the app containing the view
    that extends this class
    """

    request = None

    def get_context_data(self, **kwargs) -> dict:
        app_name = sys.modules[
            resolve(self.request.path_info).func.__module__
        ].__package__
        self.channel_name = app_name
        self.websocket_route_key = app_name

        return super().get_context_data(**kwargs)



#!/usr/bin/env python
import os
import sys

if __name__ == "__main__":
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "make_migrations_settings")
    from django.core.management import execute_from_command_line

    args = sys.argv + ["makemigrations", "django_aws_api_gateway_websockets"]
    execute_from_command_line(args)



#!/usr/bin/env python
import os
import subprocess
import sys
from pathlib import Path

if __name__ == "__main__":
    py_version = sys.version_info[:3]

    os.chdir(Path(__file__).parent)
    os.environ["CUSTOM_COMPILE_COMMAND"] = "requirements/compile.py"
    os.environ["PIP_REQUIRE_VIRTUALENV"] = "0"
    common_args = [
        "-m",
        "piptools",
        "compile",
        "--generate-hashes",
        "--allow-unsafe",
        "--no-emit-index-url"
    ] + sys.argv[1:]

    if (3, 10, 0) <= py_version < (3, 11, 0):
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=4.2.26,<5",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py310-django42.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.1.14,<5.2",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py310-django51.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.2.8,<6.0",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py310-django52.txt",
            ],
            check=True,
            capture_output=True,
        )
    if (3, 11, 0) <= py_version < (3, 12, 0):
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=4.2.26,<5",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py311-django42.txt",
            ],
            check=True,
            capture_output=True,
        )
        # Django 5 required Python 3.10+
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.1.14,<5.2",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py311-django51.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.2.8,<6.0",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py311-django52.txt",
            ],
            check=True,
            capture_output=True,
        )
    if (3, 12, 0) <= py_version < (3, 13, 0):
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=4.2.26,<5",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py312-django42.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.1.14,<5.2",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py312-django51.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.2.8,<6.0",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py312-django52.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=6.0,<6.1",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py312-django60.txt",
            ],
            check=True,
            capture_output=True,
        )
    if (3, 13, 0) <= py_version < (3, 15, 0):
        # Python 3.13
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=4.2.26,<5",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py313-django42.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.1.14,<5.2",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py313-django51.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.2.8,<6.0",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py313-django52.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=6.0,<6.1",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py313-django60.txt",
            ],
            check=True,
            capture_output=True,
        )
        # Python 3.14
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=4.2.26,<5",
                "-P",
                "urllib3>=2.6.0",
                "-P",
                "sqlparse>=0.5.4",
                "-o",
                "py314-django42.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.1.14,<5.2",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py314-django51.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=5.2.8,<6.0",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py314-django52.txt",
            ],
            check=True,
            capture_output=True,
        )
        subprocess.run(
            [
                "python",
                *common_args,
                "-P",
                "Django>=6,<6.1",
                "-P",
                "urllib3>=2.6.0",
                "-o",
                "py314-django60.txt",
            ],
            check=True,
            capture_output=True,
        )



import os
import random
import string

import django

BASE_DIR = os.path.dirname(os.path.dirname(__file__))
DEBUG = False
TEMPLATE_DEBUG = DEBUG

characters = string.ascii_letters + string.digits
SECRET_KEY = "".join(random.choice(characters) for i in range(48))

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": os.path.join(BASE_DIR, "db.sqlite3"),
    }
}

ALLOWED_HOSTS: []

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django_aws_api_gateway_websockets",
    "tests",
]

MIDDLEWARE = [
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "django.middleware.security.SecurityMiddleware",
]

ROOT_URLCONF = "tests.urls"
TIME_ZONE = "UTC"
USE_I18N = True
USE_TZ = True

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "OPTIONS": {
            "context_processors": ["django.contrib.auth.context_processors.auth"]
        },
    }
]

AUTH_USER_MODEL = "auth.User"

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"
